/*
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0.  If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Copyright 1997 - July 2008 CWI, August 2008 - 2018 MonetDB B.V.
 */

/*  (co) M.L. Kersten */
#ifndef _SQL_STATISTICS_DEF
#define _SQL_STATISTICS_DEF

/* #define DEBUG_SQL_STATISTICS */

#include "sql.h"

sql5_export str sql_analyze(Client cntxt, MalBlkPtr mb, MalStkPtr stk, InstrPtr pci);

#endif /* _SQL_STATISTICS_DEF */
